package lotus.domino.local;

import java.util.Enumeration;
import java.util.Vector;
import lotus.domino.DateTime;
import lotus.domino.DocumentCollection;
import lotus.domino.NotesException;
import lotus.domino.ViewEntryCollection;
import lotus.notes.JavaString;

public class View extends NotesBase implements lotus.domino.View {
   protected transient Database database;
   private transient Vector columns;

   private native void Nclear();

   private native int NFTSearch(String var1, int var2);

   private native int NgetChild(Document var1);

   private native int NgetDocumentByKey(Vector var1, boolean var2);

   private native int NgetAllDocumentsByKey(Vector var1, boolean var2);

   private native int NgetFirstDocument();

   private native int NgetLastDocument();

   private native int NgetNextDocument(Document var1);

   private native int NgetNextSibling(Document var1);

   private native int NgetNthDocument(int var1);

   private native int NgetParentDocument(Document var1);

   private native int NgetPrevDocument(Document var1);

   private native int NgetPrevSibling(Document var1);

   private native void Nrefresh();

   private native void Nremove();

   protected native int NgetOneViewEntry(CollectionPos var1, int var2, int var3, int var4, int var5, int var6);

   private native int NgetEntryByKey(Vector var1, boolean var2);

   private native int NgetAllEntriesByKey(Vector var1, boolean var2);

   private native int NgetAllEntries();

   protected View() throws NotesException {
   }

   protected View(Database var1, int var2) throws NotesException {
      super(var2, 3);
      if (var1 == null) {
         throw new NotesException(4405, JavaString.resource.getString("missing_db_object"));
      } else {
         this.database = var1;
         this.columns = new Vector(3);
         var1.AddView(this);
      }
   }

   protected void InternalFinalize() throws NotesException {
      try {
         Enumeration var3 = this.columns.elements();

         while(var3.hasMoreElements()) {
            ViewColumn var4 = (ViewColumn)var3.nextElement();
            super.DestroyObject(var4);
         }
      } catch (Exception var7) {
      } finally {
         this.columns.removeAllElements();
         super.finalize();
      }

   }

   public void finalize() throws NotesException {
      this.database.RemoveView(this);
      this.InternalFinalize();
   }

   protected void AddColumn(ViewColumn var1) throws NotesException {
      ((NotesBase)this).CheckObject();
      Vector var2 = this.columns;
      synchronized(var2){}

      try {
         this.columns.addElement(var1);
      } catch (Throwable var4) {
         throw var4;
      }

   }

   protected void RemoveColumn(ViewColumn var1) throws NotesException {
      Vector var2 = this.columns;
      synchronized(var2){}

      try {
         this.columns.removeElement(var1);
      } catch (Throwable var4) {
         throw var4;
      }

   }

   protected ViewColumn FindOrCreateColumn(int var1) throws NotesException {
      ((NotesBase)this).CheckObject();
      if (var1 == 0) {
         return null;
      } else {
         Vector var4 = this.columns;
         synchronized(var4){}

         ViewColumn var3;
         try {
            Enumeration var6 = this.columns.elements();

            ViewColumn var2;
            do {
               if (!var6.hasMoreElements()) {
                  var3 = new ViewColumn(this, var1);
                  return var3;
               }

               var2 = (ViewColumn)var6.nextElement();
            } while(!((NotesBase)var2).isEqual(var1));

            var3 = var2;
         } catch (Throwable var8) {
            throw var8;
         }

         return var3;
      }
   }

   private ViewNavigator makeViewNavigator(byte var1, boolean var2, int var3, Object var4) throws NotesException {
      int var5 = 30;
      boolean var6 = true;
      if (((NotesBase)this).PropGetBool(1927) || ((NotesBase)this).PropGetBool(1920)) {
         var6 = false;
      }

      if (var1 != 0) {
         if (var4 == null) {
            if (var1 != 4) {
               throw new NotesException(4447, JavaString.resource.getString("missing_viewentry_or_document_object"));
            }

            var1 = 5;
         } else if (var4 instanceof ViewEntry && !((ViewEntry)var4).isValid() || var4 instanceof Document && !((Document)var4).isValid()) {
            throw new NotesException(4376, "object_deleted");
         }
      }

      if (var1 != 0 && var4 instanceof ViewEntry && ((ViewEntry)var4).getParentView() != this) {
         throw new NotesException(4450, JavaString.resource.getString("cannot_construct_viewnavigator_from_category_entry_from_a_different_view"));
      } else {
         if (var2) {
            if (var3 < 0 || var3 > 30) {
               throw new NotesException(4392, JavaString.resource.getString("invalid_maximum_navigation_level"));
            }

            var5 = var3;
         }

         ViewNavigator var7 = new ViewNavigator(this, var1, var6, var4, var5);
         return var7;
      }
   }

   public void recycle() throws NotesException {
      try {
         this.database.RemoveView(this);
         Enumeration var3 = this.columns.elements();

         while(var3.hasMoreElements()) {
            ViewColumn var4 = (ViewColumn)var3.nextElement();
            super.RecycleObject(var4);
         }
      } catch (NotesException var7) {
      } finally {
         this.columns.removeAllElements();
         super.Recycle();
      }

   }

   public void clear() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      try {
         this.Nclear();
      } catch (Throwable var3) {
         throw var3;
      }

   }

   public int FTSearch(String var1, int var2) throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      int var3;
      try {
         var3 = this.NFTSearch(var1, var2);
      } catch (Throwable var7) {
         throw var7;
      }

      return var3;
   }

   public int FTSearch(String var1) throws NotesException {
      return this.FTSearch(var1, 0);
   }

   public lotus.domino.Document getChild(lotus.domino.Document var1) throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      Document var2;
      try {
         if (var1 == null) {
            throw new NotesException(4406, JavaString.resource.getString("missing_document_object"));
         }

         var2 = this.database.FindOrCreateDocument(this.NgetChild((Document)var1));
      } catch (Throwable var6) {
         throw var6;
      }

      return var2;
   }

   public lotus.domino.Document getDocumentByKey(Vector var1) throws NotesException {
      return this.getDocumentByKey(var1, false);
   }

   public lotus.domino.Document getDocumentByKey(Vector var1, boolean var2) throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      Document var3;
      try {
         var3 = this.database.FindOrCreateDocument(this.NgetDocumentByKey(var1, var2));
      } catch (Throwable var7) {
         throw var7;
      }

      return var3;
   }

   public lotus.domino.Document getDocumentByKey(Object var1) throws NotesException {
      Vector var2 = new Vector(1);
      var2.addElement(var1);
      return this.getDocumentByKey(var2, false);
   }

   public lotus.domino.Document getDocumentByKey(Object var1, boolean var2) throws NotesException {
      Vector var3 = new Vector(1);
      var3.addElement(var1);
      return this.getDocumentByKey(var3, var2);
   }

   public DocumentCollection getAllDocumentsByKey(Vector var1) throws NotesException {
      return this.getAllDocumentsByKey(var1, false);
   }

   public DocumentCollection getAllDocumentsByKey(Vector var1, boolean var2) throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      lotus.domino.local.DocumentCollection var3;
      try {
         var3 = this.database.FindOrCreateDocCollection(this.NgetAllDocumentsByKey(var1, var2));
      } catch (Throwable var7) {
         throw var7;
      }

      return var3;
   }

   public DocumentCollection getAllDocumentsByKey(Object var1) throws NotesException {
      Vector var2 = new Vector(1);
      var2.addElement(var1);
      return this.getAllDocumentsByKey(var2, false);
   }

   public DocumentCollection getAllDocumentsByKey(Object var1, boolean var2) throws NotesException {
      Vector var3 = new Vector(1);
      var3.addElement(var1);
      return this.getAllDocumentsByKey(var3, var2);
   }

   public lotus.domino.ViewEntry getEntryByKey(Vector var1) throws NotesException {
      return this.getEntryByKey(var1, false);
   }

   public lotus.domino.ViewEntry getEntryByKey(Vector var1, boolean var2) throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      ViewEntry var3;
      try {
         var3 = new ViewEntry(this, this.NgetEntryByKey(var1, var2), (CollectionPos)null);
      } catch (Throwable var7) {
         throw var7;
      }

      return var3;
   }

   public lotus.domino.ViewEntry getEntryByKey(Object var1) throws NotesException {
      Vector var2 = new Vector(1);
      var2.addElement(var1);
      return this.getEntryByKey(var2, false);
   }

   public lotus.domino.ViewEntry getEntryByKey(Object var1, boolean var2) throws NotesException {
      Vector var3 = new Vector(1);
      var3.addElement(var1);
      return this.getEntryByKey(var3, var2);
   }

   public ViewEntryCollection getAllEntriesByKey(Vector var1) throws NotesException {
      return this.getAllEntriesByKey(var1, false);
   }

   public ViewEntryCollection getAllEntriesByKey(Vector var1, boolean var2) throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      lotus.domino.local.ViewEntryCollection var3;
      try {
         var3 = new lotus.domino.local.ViewEntryCollection(this, this.NgetAllEntriesByKey(var1, var2));
      } catch (Throwable var7) {
         throw var7;
      }

      return var3;
   }

   public ViewEntryCollection getAllEntriesByKey(Object var1) throws NotesException {
      Vector var2 = new Vector(1);
      var2.addElement(var1);
      return this.getAllEntriesByKey(var2, false);
   }

   public ViewEntryCollection getAllEntriesByKey(Object var1, boolean var2) throws NotesException {
      Vector var3 = new Vector(1);
      var3.addElement(var1);
      return this.getAllEntriesByKey(var3, var2);
   }

   public ViewEntryCollection getAllEntries() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      lotus.domino.local.ViewEntryCollection var1;
      try {
         var1 = new lotus.domino.local.ViewEntryCollection(this, this.NgetAllEntries());
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public lotus.domino.Document getFirstDocument() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      Document var1;
      try {
         var1 = this.database.FindOrCreateDocument(this.NgetFirstDocument());
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public lotus.domino.Document getLastDocument() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      Document var1;
      try {
         var1 = this.database.FindOrCreateDocument(this.NgetLastDocument());
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public lotus.domino.Document getNextDocument(lotus.domino.Document var1) throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      Document var2;
      try {
         if (var1 == null) {
            throw new NotesException(4406, JavaString.resource.getString("missing_document_object"));
         }

         var2 = this.database.FindOrCreateDocument(this.NgetNextDocument((Document)var1));
      } catch (Throwable var6) {
         throw var6;
      }

      return var2;
   }

   public lotus.domino.Document getNextSibling(lotus.domino.Document var1) throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      Document var2;
      try {
         if (var1 == null) {
            throw new NotesException(4406, JavaString.resource.getString("missing_document_object"));
         }

         var2 = this.database.FindOrCreateDocument(this.NgetNextSibling((Document)var1));
      } catch (Throwable var6) {
         throw var6;
      }

      return var2;
   }

   public lotus.domino.Document getNthDocument(int var1) throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      Document var2;
      try {
         var2 = this.database.FindOrCreateDocument(this.NgetNthDocument(var1));
      } catch (Throwable var6) {
         throw var6;
      }

      return var2;
   }

   public lotus.domino.Document getParentDocument(lotus.domino.Document var1) throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      Document var2;
      try {
         if (var1 == null) {
            throw new NotesException(4406, JavaString.resource.getString("missing_document_object"));
         }

         var2 = this.database.FindOrCreateDocument(this.NgetParentDocument((Document)var1));
      } catch (Throwable var6) {
         throw var6;
      }

      return var2;
   }

   public lotus.domino.Document getPrevDocument(lotus.domino.Document var1) throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      Document var2;
      try {
         if (var1 == null) {
            throw new NotesException(4406, JavaString.resource.getString("missing_document_object"));
         }

         var2 = this.database.FindOrCreateDocument(this.NgetPrevDocument((Document)var1));
      } catch (Throwable var6) {
         throw var6;
      }

      return var2;
   }

   public lotus.domino.Document getPrevSibling(lotus.domino.Document var1) throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      Document var2;
      try {
         if (var1 == null) {
            throw new NotesException(4406, JavaString.resource.getString("missing_document_object"));
         }

         var2 = this.database.FindOrCreateDocument(this.NgetPrevSibling((Document)var1));
      } catch (Throwable var6) {
         throw var6;
      }

      return var2;
   }

   public void refresh() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      try {
         this.Nrefresh();
      } catch (Throwable var3) {
         throw var3;
      }

   }

   public void remove() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      try {
         this.Nremove();
         this.database.RemoveView(this);
         super.cpp_object = 0;
         this.finalize();
      } catch (Throwable var3) {
         throw var3;
      }

   }

   public DateTime getCreated() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      lotus.domino.local.DateTime var1;
      try {
         var1 = ((Session)this.database.getParent()).FindOrCreateDateTime(((NotesBase)this).PropGetDate(1282));
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public DateTime getLastModified() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      lotus.domino.local.DateTime var1;
      try {
         var1 = ((Session)this.database.getParent()).FindOrCreateDateTime(((NotesBase)this).PropGetDate(1281));
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public String getName() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      String var1;
      try {
         var1 = ((NotesBase)this).PropGetString(1280);
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public String toString() {
      String var1;
      try {
         var1 = this.getName();
      } catch (Exception var2) {
         var1 = null;
      }

      return var1;
   }

   public String getUniversalID() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      String var1;
      try {
         var1 = ((NotesBase)this).PropGetString(1283);
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public lotus.domino.Database getParent() throws NotesException {
      ((NotesBase)this).CheckObject();
      return this.database;
   }

   public boolean isDefaultView() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      boolean var1;
      try {
         var1 = ((NotesBase)this).PropGetBool(1285);
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public boolean isFolder() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      boolean var1;
      try {
         var1 = ((NotesBase)this).PropGetBool(1287);
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public Vector getColumns() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      Vector var1;
      try {
         int[] var4 = ((NotesBase)this).PropGetObjArray(1286);
         if (var4.length != 0) {
            Vector var7 = new Vector(var4.length);

            for(int var6 = 0; var6 < var4.length; ++var6) {
               ViewColumn var5 = this.FindOrCreateColumn(var4[var6]);
               var7.addElement(var5);
            }

            var1 = var7;
            return var1;
         }

         var1 = null;
      } catch (Throwable var9) {
         throw var9;
      }

      return var1;
   }

   public Vector getReaders() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      Vector var2;
      try {
         String[] var5 = ((NotesBase)this).PropGetStringArray(1302);
         Vector var1;
         if (var5 != null && var5.length > 0) {
            var1 = new Vector(var5.length, 1);

            for(int var6 = 0; var6 < var5.length; ++var6) {
               var1.addElement(var5[var6]);
            }
         } else {
            var1 = new Vector(1);
         }

         var2 = var1;
      } catch (Throwable var8) {
         throw var8;
      }

      return var2;
   }

   public void setReaders(Vector var1) throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      try {
         ((NotesBase)this).PropSetVector(1302, var1);
      } catch (Throwable var4) {
         throw var4;
      }

   }

   public boolean isAutoUpdate() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      boolean var1;
      try {
         var1 = ((NotesBase)this).PropGetBool(1303);
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public void setAutoUpdate(boolean var1) throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      try {
         ((NotesBase)this).PropSetBool(1303, var1);
      } catch (Throwable var4) {
         throw var4;
      }

   }

   public Vector getAliases() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      Vector var2;
      try {
         String[] var5 = ((NotesBase)this).PropGetStringArray(1304);
         Vector var1;
         if (var5 != null && var5.length > 0) {
            var1 = new Vector(var5.length, 1);

            for(int var6 = 0; var6 < var5.length; ++var6) {
               var1.addElement(var5[var6]);
            }
         } else {
            var1 = new Vector(1);
         }

         var2 = var1;
      } catch (Throwable var8) {
         throw var8;
      }

      return var2;
   }

   public boolean isCalendar() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      boolean var1;
      try {
         var1 = ((NotesBase)this).PropGetBool(1305);
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public boolean isProtectReaders() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      boolean var1;
      try {
         var1 = ((NotesBase)this).PropGetBool(1309);
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public void setProtectReaders(boolean var1) throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      try {
         ((NotesBase)this).PropSetBool(1309, var1);
      } catch (Throwable var4) {
         throw var4;
      }

   }

   public boolean isModified() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      boolean var1;
      try {
         var1 = ((NotesBase)this).PropGetBool(1925);
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public boolean isCategorized() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      boolean var1;
      try {
         var1 = ((NotesBase)this).PropGetBool(1927);
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public boolean isPrivate() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      boolean var1;
      try {
         var1 = ((NotesBase)this).PropGetBool(1310);
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public boolean isConflict() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      boolean var1;
      try {
         var1 = ((NotesBase)this).PropGetBool(1921);
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public boolean isHierarchical() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      boolean var1;
      try {
         var1 = ((NotesBase)this).PropGetBool(1920);
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public int getColumnCount() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      int var1;
      try {
         var1 = ((NotesBase)this).PropGetInt(1928);
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public int getBackgroundColor() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      int var1;
      try {
         var1 = ((NotesBase)this).PropGetInt(1926);
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public int getRowLines() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      int var1;
      try {
         var1 = ((NotesBase)this).PropGetInt(1922);
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public int getHeaderLines() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      int var1;
      try {
         var1 = ((NotesBase)this).PropGetInt(1923);
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public int getSpacing() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      int var1;
      try {
         var1 = ((NotesBase)this).PropGetInt(1924);
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public int getTopLevelEntryCount() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      int var1;
      try {
         var1 = ((NotesBase)this).PropGetInt(1929);
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public lotus.domino.ViewColumn getColumn(int var1) throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      lotus.domino.ViewColumn var2;
      try {
         int[] var5 = ((NotesBase)this).PropGetObjArray(1286);
         if (var5.length != 0) {
            if (var1 >= 1 && var1 <= var5.length) {
               ViewColumn var6 = this.FindOrCreateColumn(var5[var1 - 1]);
               var2 = var6;
               return var2;
            }

            throw new NotesException(4396, JavaString.resource.getString("invalid_view_column_number"));
         }

         var2 = null;
      } catch (Throwable var8) {
         throw var8;
      }

      return var2;
   }

   public Vector getColumnNames() throws NotesException {
      ((NotesBase)this).CheckObject();
      synchronized(this){}

      Vector var2;
      try {
         int var5 = ((NotesBase)this).PropGetInt(1928);
         Vector var1 = new Vector(var5);
         int[] var6 = ((NotesBase)this).PropGetObjArray(1286);
         if (var6.length != 0) {
            for(int var7 = 0; var7 < var5; ++var7) {
               ViewColumn var8 = this.FindOrCreateColumn(var6[var7]);
               var1.addElement(var8.getTitle());
            }

            var2 = var1;
            return var2;
         }

         var2 = var1;
      } catch (Throwable var10) {
         throw var10;
      }

      return var2;
   }

   public lotus.domino.ViewNavigator createViewNav() throws NotesException {
      ((NotesBase)this).CheckObject();
      return this.makeViewNavigator((byte)0, false, 0, (Object)null);
   }

   public lotus.domino.ViewNavigator createViewNav(int var1) throws NotesException {
      return this.createViewNav();
   }

   public lotus.domino.ViewNavigator createViewNavMaxLevel(int var1) throws NotesException {
      ((NotesBase)this).CheckObject();
      return this.makeViewNavigator((byte)0, true, var1, (Object)null);
   }

   public lotus.domino.ViewNavigator createViewNavMaxLevel(int var1, int var2) throws NotesException {
      return this.createViewNavMaxLevel(var1);
   }

   public lotus.domino.ViewNavigator createViewNavFrom(Object var1) throws NotesException {
      ((NotesBase)this).CheckObject();
      return this.makeViewNavigator((byte)3, false, 0, var1);
   }

   public lotus.domino.ViewNavigator createViewNavFrom(Object var1, int var2) throws NotesException {
      return this.createViewNavFrom(var1);
   }

   public lotus.domino.ViewNavigator createViewNavFromChildren(Object var1) throws NotesException {
      ((NotesBase)this).CheckObject();
      return this.makeViewNavigator((byte)1, false, 0, var1);
   }

   public lotus.domino.ViewNavigator createViewNavFromChildren(Object var1, int var2) throws NotesException {
      return this.createViewNavFromChildren(var1);
   }

   public lotus.domino.ViewNavigator createViewNavFromDescendants(Object var1) throws NotesException {
      ((NotesBase)this).CheckObject();
      return this.makeViewNavigator((byte)2, false, 0, var1);
   }

   public lotus.domino.ViewNavigator createViewNavFromDescendants(Object var1, int var2) throws NotesException {
      return this.createViewNavFromDescendants(var1);
   }

   public lotus.domino.ViewNavigator createViewNavFromCategory(String var1) throws NotesException {
      ((NotesBase)this).CheckObject();
      Vector var2 = new Vector(1);
      var2.addElement(var1);
      return this.makeViewNavigator((byte)4, false, 0, this.getDocumentByKey(var2, true));
   }

   public lotus.domino.ViewNavigator createViewNavFromCategory(String var1, int var2) throws NotesException {
      return this.createViewNavFromCategory(var1);
   }
}
