package lotus.domino.local;

import lotus.domino.NotesException;
import lotus.notes.JavaString;

public class ViewNavigator extends NotesBase implements lotus.domino.ViewNavigator {
   protected transient View parentView;
   private transient int maxLevel = 30;
   private transient int navMinLevel;
   private transient int navMaxLevel = 30;
   private transient boolean navFlat;
   private transient boolean isEmpty = true;
   protected transient short navType;
   private transient ViewEntry currEntry;
   private transient CollectionPos currPos = new CollectionPos();
   private transient CollectionPos startPos;
   private static final short MAX_TUMBLER_LEVELS = 32;
   private static final int SIGNAL_ANY_CONFLICT = 31;

   protected ViewNavigator(View var1, int var2, boolean var3, Object var4, int var5) throws NotesException {
      super(0, 3);
      this.parentView = var1;
      this.navFlat = var3;
      this.navType = (short)var2;
      this.navMaxLevel = this.maxLevel = var5;
      if (var2 != 5) {
         this.navType = (short)var2;
         this.initialFill(var4);
      }

   }

   protected void initialFill(Object var1) throws NotesException {
      CollectionPos var2 = null;
      long var3 = 0L;
      int var6 = 0;
      boolean var5;
      if (var1 == null) {
         var5 = this.navigateEntry(0, (CollectionPos)null, 0L);
      } else {
         if (var1 instanceof ViewEntry) {
            ViewEntry var7 = (ViewEntry)var1;
            if (var7.getParentView() == this.parentView) {
               var2 = var7.pos;
            } else {
               var6 = Integer.parseInt(var7.getNoteID(), 16);
            }
         } else {
            if (!(var1 instanceof Document)) {
               throw new NotesException(4391, JavaString.resource.getString("specified_object_must_be_a_viewentry_or_document"));
            }

            var6 = ((Document)var1).getLNoteID();
         }

         if (var2 == null) {
            ViewEntry var8 = this.mkViewEntry(this.parentView, this, var6);
            var2 = var8.pos;
         }

         switch (this.navType) {
            case 1:
               this.navMaxLevel = var2.level + 1;
            case 2:
               this.navMinLevel = var2.level + 1;
               var5 = this.navigateEntry(4, var2, var3);
               break;
            case 4:
               this.navMinLevel = var2.level + 1;
            case 3:
            default:
               var5 = this.navigateEntry(0, var2, var3);
         }
      }

      if (var5) {
         this.isEmpty = false;
         this.startPos = new CollectionPos();
         this.startPos.copyPos(this.currPos);
      }

   }

   protected void CheckObject() throws NotesException {
      this.parentView.CheckObject();
      super.CheckObject();
   }

   private boolean navigateEntry(int var1, CollectionPos var2, long var3) throws NotesException {
      long var5 = 1L;
      CollectionPos var7 = new CollectionPos();
      if (var1 == 32769) {
         var5 = -1L;
      } else if (var1 == 0) {
         var5 = 0L;
      }

      if (var2 != null) {
         var7.copyPos(var2);
      } else if (var1 != 0 && var1 != 32769) {
         var7.copyPos(this.currPos);
      } else if (this.navType != 0 && this.startPos != null) {
         var7.copyPos(this.startPos);
      } else {
         var7.level = 0;
         var7.tumbler = new int[32];
         var7.tumbler[0] = 1;
      }

      var7.minLevel = 0;
      var7.maxLevel = 30;
      if (this.navMinLevel > 0) {
         var7.minLevel = this.navMinLevel;
         var1 |= 256;
      }

      if (this.maxLevel < 30 || this.navMaxLevel < 30) {
         var7.maxLevel = this.maxLevel < this.navMaxLevel ? this.maxLevel : this.navMaxLevel;
         var1 |= 512;
      }

      return this.getEntry(var1, var3, var5, var7, 0L);
   }

   private boolean getEntry(int var1, long var2, long var4, CollectionPos var6, long var7) throws NotesException {
      var2 |= 25787L;
      int var9 = this.parentView.NgetOneViewEntry(var6, (int)var7, var1, (int)var4, 0, (int)var2);
      if (var9 == 0) {
         this.currEntry = null;
         return false;
      } else {
         this.currEntry = new ViewEntry(this, var9, var6);
         this.currPos.copyPos(var6);
         return true;
      }
   }

   private ViewEntry mkViewEntry(View var1, Object var2, int var3) throws NotesException {
      CollectionPos var5 = new CollectionPos();
      var5.tumbler = new int[32];
      var5.tumbler[0] = var3;
      int var4 = this.parentView.NgetOneViewEntry(var5, var3, 0, 0, 1, 156859);
      return var4 == 0 ? null : new ViewEntry(this, var4, var5);
   }

   private boolean gotoRelEntry(int var1, ViewEntry var2) throws NotesException {
      boolean var3 = false;
      this.CheckObject();
      if (!this.isEmpty) {
         synchronized(this){}

         try {
            if (var2 == null) {
               throw new NotesException(4446, JavaString.resource.getString("missing_viewentry_object"));
            }

            if (var2.parent != this) {
               throw new NotesException(4394, JavaString.resource.getString("specified_viewentry_not_created_from_this_viewnavigator"));
            }

            var3 = this.navigateEntry(var1, var2.pos, 0L);
         } catch (Throwable var6) {
            throw var6;
         }
      }

      return var3;
   }

   private CollectionPos buildPos(String var1, char var2) throws NotesException {
      short var4 = 0;
      if (var1.length() == 0) {
         throw new NotesException(4393, JavaString.resource.getString("invalid_position_string"));
      } else {
         CollectionPos var6 = new CollectionPos();

         int var5;
         for(var6.tumbler = new int[32]; var4 < 32; var1 = var1.substring(var5 + 1)) {
            var5 = var1.indexOf(var2);
            if (var5 < 0) {
               break;
            }

            if (var5 == 0) {
               throw new NotesException(4393, JavaString.resource.getString("invalid_position_string"));
            }

            String var3 = var1.substring(0, var5);
            var6.tumbler[var4++] = Integer.parseInt(var3);
            if (var1.length() <= var5) {
               throw new NotesException(4393, JavaString.resource.getString("invalid_position_string"));
            }
         }

         if (var4 == 32) {
            throw new NotesException(4393, JavaString.resource.getString("invalid_position_string"));
         } else {
            var6.tumbler[var4] = Integer.parseInt(var1);
            var6.level = var4;
            var6.minLevel = 0;
            var6.maxLevel = 32;
            return var6;
         }
      }
   }

   public boolean gotoFirst() throws NotesException {
      this.CheckObject();
      if (this.isEmpty) {
         return false;
      } else {
         synchronized(this){}

         boolean var1;
         try {
            var1 = this.navigateEntry(0, (CollectionPos)null, 0L);
         } catch (Throwable var5) {
            throw var5;
         }

         return var1;
      }
   }

   public lotus.domino.ViewEntry getFirst() throws NotesException {
      this.CheckObject();
      if (this.isEmpty) {
         return null;
      } else {
         synchronized(this){}

         ViewEntry var1;
         try {
            this.gotoFirst();
            var1 = this.currEntry;
         } catch (Throwable var5) {
            throw var5;
         }

         return var1;
      }
   }

   public boolean gotoFirstDocument() throws NotesException {
      this.CheckObject();
      if (this.isEmpty) {
         return false;
      } else {
         synchronized(this){}

         boolean var1;
         try {
            if (!this.gotoFirst()) {
               var1 = false;
               return var1;
            }

            if (this.currEntry.isCategory() || this.currEntry.isTotal()) {
               var1 = this.navigateEntry(43, (CollectionPos)null, 0L);
               return var1;
            }

            var1 = true;
         } catch (Throwable var5) {
            throw var5;
         }

         return var1;
      }
   }

   public lotus.domino.ViewEntry getFirstDocument() throws NotesException {
      this.CheckObject();
      if (this.isEmpty) {
         return null;
      } else {
         synchronized(this){}

         ViewEntry var1;
         try {
            this.gotoFirstDocument();
            var1 = this.currEntry;
         } catch (Throwable var5) {
            throw var5;
         }

         return var1;
      }
   }

   public boolean gotoNext() throws NotesException {
      this.CheckObject();
      if (this.isEmpty) {
         return false;
      } else {
         synchronized(this){}

         boolean var1;
         try {
            var1 = this.navigateEntry(1, (CollectionPos)null, 0L);
         } catch (Throwable var5) {
            throw var5;
         }

         return var1;
      }
   }

   public lotus.domino.ViewEntry getNext() throws NotesException {
      this.CheckObject();
      if (this.isEmpty) {
         return null;
      } else {
         synchronized(this){}

         ViewEntry var1;
         try {
            this.gotoNext();
            var1 = this.currEntry;
         } catch (Throwable var5) {
            throw var5;
         }

         return var1;
      }
   }

   public boolean gotoNextCategory() throws NotesException {
      this.CheckObject();
      if (this.isEmpty) {
         return false;
      } else {
         synchronized(this){}

         boolean var1;
         try {
            var1 = this.navigateEntry(41, (CollectionPos)null, 0L);
         } catch (Throwable var5) {
            throw var5;
         }

         return var1;
      }
   }

   public boolean gotoNextDocument() throws NotesException {
      this.CheckObject();
      if (this.isEmpty) {
         return false;
      } else {
         synchronized(this){}

         boolean var1;
         try {
            var1 = this.navigateEntry(43, (CollectionPos)null, 0L);
         } catch (Throwable var5) {
            throw var5;
         }

         return var1;
      }
   }

   public lotus.domino.ViewEntry getNextCategory() throws NotesException {
      this.CheckObject();
      if (this.isEmpty) {
         return null;
      } else {
         synchronized(this){}

         ViewEntry var1;
         try {
            this.gotoNextCategory();
            var1 = this.currEntry;
         } catch (Throwable var5) {
            throw var5;
         }

         return var1;
      }
   }

   public lotus.domino.ViewEntry getNextDocument() throws NotesException {
      this.CheckObject();
      if (this.isEmpty) {
         return null;
      } else {
         synchronized(this){}

         ViewEntry var1;
         try {
            this.gotoNextDocument();
            var1 = this.currEntry;
         } catch (Throwable var5) {
            throw var5;
         }

         return var1;
      }
   }

   public boolean gotoPrev() throws NotesException {
      this.CheckObject();
      if (this.isEmpty) {
         return false;
      } else {
         synchronized(this){}

         boolean var1;
         try {
            var1 = this.navigateEntry(9, (CollectionPos)null, 0L);
         } catch (Throwable var5) {
            throw var5;
         }

         return var1;
      }
   }

   public lotus.domino.ViewEntry getPrev() throws NotesException {
      this.CheckObject();
      if (this.isEmpty) {
         return null;
      } else {
         synchronized(this){}

         ViewEntry var1;
         try {
            this.gotoPrev();
            var1 = this.currEntry;
         } catch (Throwable var5) {
            throw var5;
         }

         return var1;
      }
   }

   public boolean gotoPrevCategory() throws NotesException {
      this.CheckObject();
      if (this.isEmpty) {
         return false;
      } else {
         synchronized(this){}

         boolean var1;
         try {
            var1 = this.navigateEntry(42, (CollectionPos)null, 0L);
         } catch (Throwable var5) {
            throw var5;
         }

         return var1;
      }
   }

   public boolean gotoPrevDocument() throws NotesException {
      this.CheckObject();
      if (this.isEmpty) {
         return false;
      } else {
         synchronized(this){}

         boolean var1;
         try {
            var1 = this.navigateEntry(44, (CollectionPos)null, 0L);
         } catch (Throwable var5) {
            throw var5;
         }

         return var1;
      }
   }

   public lotus.domino.ViewEntry getPrevCategory() throws NotesException {
      this.CheckObject();
      if (this.isEmpty) {
         return null;
      } else {
         synchronized(this){}

         ViewEntry var1;
         try {
            this.gotoPrevCategory();
            var1 = this.currEntry;
         } catch (Throwable var5) {
            throw var5;
         }

         return var1;
      }
   }

   public lotus.domino.ViewEntry getPrevDocument() throws NotesException {
      this.CheckObject();
      if (this.isEmpty) {
         return null;
      } else {
         synchronized(this){}

         ViewEntry var1;
         try {
            this.gotoPrevDocument();
            var1 = this.currEntry;
         } catch (Throwable var5) {
            throw var5;
         }

         return var1;
      }
   }

   public lotus.domino.ViewEntry getCurrent() throws NotesException {
      this.CheckObject();
      return this.currEntry;
   }

   public boolean gotoLast() throws NotesException {
      this.CheckObject();
      if (this.isEmpty) {
         return false;
      } else {
         synchronized(this){}

         boolean var1;
         try {
            var1 = this.navigateEntry(32769, (CollectionPos)null, 0L);
         } catch (Throwable var5) {
            throw var5;
         }

         return var1;
      }
   }

   public lotus.domino.ViewEntry getLast() throws NotesException {
      this.CheckObject();
      if (this.isEmpty) {
         return null;
      } else {
         synchronized(this){}

         ViewEntry var1;
         try {
            this.gotoLast();
            var1 = this.currEntry;
         } catch (Throwable var5) {
            throw var5;
         }

         return var1;
      }
   }

   public boolean gotoLastDocument() throws NotesException {
      this.CheckObject();
      if (this.isEmpty) {
         return false;
      } else {
         synchronized(this){}

         boolean var1;
         try {
            if (!this.gotoLast()) {
               var1 = false;
               return var1;
            }

            if (this.currEntry.isCategory() || this.currEntry.isTotal()) {
               var1 = this.navigateEntry(44, (CollectionPos)null, 0L);
               return var1;
            }

            var1 = true;
         } catch (Throwable var5) {
            throw var5;
         }

         return var1;
      }
   }

   public lotus.domino.ViewEntry getLastDocument() throws NotesException {
      this.CheckObject();
      if (this.isEmpty) {
         return null;
      } else {
         synchronized(this){}

         ViewEntry var1;
         try {
            this.gotoLastDocument();
            var1 = this.currEntry;
         } catch (Throwable var5) {
            throw var5;
         }

         return var1;
      }
   }

   public boolean gotoPos(String var1, char var2) throws NotesException {
      this.CheckObject();
      if (this.isEmpty) {
         return false;
      } else {
         CollectionPos var3 = this.buildPos(var1, var2);
         synchronized(this){}

         boolean var4;
         try {
            var4 = this.navigateEntry(0, var3, 0L);
         } catch (Throwable var8) {
            throw var8;
         }

         return var4;
      }
   }

   public lotus.domino.ViewEntry getPos(String var1, char var2) throws NotesException {
      this.CheckObject();
      if (this.isEmpty) {
         return null;
      } else {
         synchronized(this){}

         ViewEntry var3;
         try {
            this.gotoPos(var1, var2);
            var3 = this.currEntry;
         } catch (Throwable var7) {
            throw var7;
         }

         return var3;
      }
   }

   public lotus.domino.ViewEntry getNth(int var1) throws NotesException {
      this.CheckObject();
      if (this.isEmpty) {
         return null;
      } else {
         CollectionPos var2 = new CollectionPos();
         var2.level = 0;
         var2.tumbler = new int[32];
         var2.tumbler[0] = var1;
         synchronized(this){}

         ViewEntry var3;
         try {
            this.navigateEntry(0, var2, 0L);
            var3 = this.currEntry;
         } catch (Throwable var7) {
            throw var7;
         }

         return var3;
      }
   }

   public boolean gotoChild() throws NotesException {
      this.CheckObject();
      if (this.isEmpty) {
         return false;
      } else {
         synchronized(this){}

         boolean var1;
         try {
            if (!this.navFlat) {
               var1 = this.navigateEntry(4, (CollectionPos)null, 0L);
               return var1;
            }

            var1 = this.gotoNext();
         } catch (Throwable var5) {
            throw var5;
         }

         return var1;
      }
   }

   public lotus.domino.ViewEntry getChild() throws NotesException {
      this.CheckObject();
      if (this.isEmpty) {
         return null;
      } else {
         synchronized(this){}

         ViewEntry var1;
         try {
            this.gotoChild();
            var1 = this.currEntry;
         } catch (Throwable var5) {
            throw var5;
         }

         return var1;
      }
   }

   public boolean gotoNextSibling() throws NotesException {
      this.CheckObject();
      if (this.isEmpty) {
         return false;
      } else {
         synchronized(this){}

         boolean var1;
         try {
            if (!this.navFlat) {
               var1 = this.navigateEntry(5, (CollectionPos)null, 0L);
               return var1;
            }

            var1 = this.gotoNext();
         } catch (Throwable var5) {
            throw var5;
         }

         return var1;
      }
   }

   public lotus.domino.ViewEntry getNextSibling() throws NotesException {
      this.CheckObject();
      if (this.isEmpty) {
         return null;
      } else {
         synchronized(this){}

         ViewEntry var1;
         try {
            this.gotoNextSibling();
            var1 = this.currEntry;
         } catch (Throwable var5) {
            throw var5;
         }

         return var1;
      }
   }

   public boolean gotoPrevSibling() throws NotesException {
      this.CheckObject();
      if (this.isEmpty) {
         return false;
      } else {
         synchronized(this){}

         boolean var1;
         try {
            if (!this.navFlat) {
               var1 = this.navigateEntry(6, (CollectionPos)null, 0L);
               return var1;
            }

            var1 = this.gotoPrev();
         } catch (Throwable var5) {
            throw var5;
         }

         return var1;
      }
   }

   public lotus.domino.ViewEntry getPrevSibling() throws NotesException {
      this.CheckObject();
      if (this.isEmpty) {
         return null;
      } else {
         synchronized(this){}

         ViewEntry var1;
         try {
            this.gotoPrevSibling();
            var1 = this.currEntry;
         } catch (Throwable var5) {
            throw var5;
         }

         return var1;
      }
   }

   public boolean gotoParent() throws NotesException {
      this.CheckObject();
      if (this.isEmpty) {
         return false;
      } else {
         synchronized(this){}

         boolean var1;
         try {
            if (!this.navFlat) {
               var1 = this.navigateEntry(3, (CollectionPos)null, 0L);
               return var1;
            }

            var1 = this.gotoPrev();
         } catch (Throwable var5) {
            throw var5;
         }

         return var1;
      }
   }

   public lotus.domino.ViewEntry getParent() throws NotesException {
      this.CheckObject();
      if (this.isEmpty) {
         return null;
      } else {
         synchronized(this){}

         ViewEntry var1;
         try {
            this.gotoParent();
            var1 = this.currEntry;
         } catch (Throwable var5) {
            throw var5;
         }

         return var1;
      }
   }

   public boolean gotoEntry(Object var1) throws NotesException {
      this.CheckObject();
      if (this.isEmpty) {
         return false;
      } else {
         int var2 = 0;
         long var3 = 0L;
         CollectionPos var5 = new CollectionPos();
         if (var1 == null) {
            throw new NotesException(4447, JavaString.resource.getString("missing_viewentry_or_document_object"));
         } else {
            if (var1 instanceof ViewEntry) {
               ViewEntry var6 = (ViewEntry)var1;
               if (!var6.isValid()) {
                  throw new NotesException(4376, "object_deleted");
               }

               if (var6.getParentView() != this.parentView) {
                  if (var6.isCategory() || var6.isTotal()) {
                     throw new NotesException(4451, JavaString.resource.getString("cannot_navigate_to_category_entry_from_a_different_view"));
                  }

                  var2 = Integer.parseInt(((ViewEntry)var1).getNoteID(), 16);
               } else {
                  var5.copyPos(var6.pos);
               }
            } else {
               if (!(var1 instanceof Document)) {
                  throw new NotesException(4391, JavaString.resource.getString("specified_object_must_be_a_viewentry_or_document"));
               }

               if (!((Document)var1).isValid()) {
                  throw new NotesException(4376, "object_deleted");
               }

               var2 = ((Document)var1).getLNoteID();
            }

            if (var2 != 0) {
               var5.tumbler = new int[32];
               var5.tumbler[0] = var2;
               var3 = 131072L;
            }

            return this.navigateEntry(0, var5, var3);
         }
      }
   }

   public boolean gotoNext(lotus.domino.ViewEntry var1) throws NotesException {
      return this.gotoRelEntry(1, (ViewEntry)var1);
   }

   public lotus.domino.ViewEntry getNext(lotus.domino.ViewEntry var1) throws NotesException {
      this.gotoNext((ViewEntry)var1);
      return this.currEntry;
   }

   public boolean gotoPrev(lotus.domino.ViewEntry var1) throws NotesException {
      return this.gotoRelEntry(9, (ViewEntry)var1);
   }

   public lotus.domino.ViewEntry getPrev(lotus.domino.ViewEntry var1) throws NotesException {
      this.gotoPrev((ViewEntry)var1);
      return this.currEntry;
   }

   public boolean gotoChild(lotus.domino.ViewEntry var1) throws NotesException {
      return this.navFlat ? this.gotoRelEntry(1, (ViewEntry)var1) : this.gotoRelEntry(4, (ViewEntry)var1);
   }

   public lotus.domino.ViewEntry getChild(lotus.domino.ViewEntry var1) throws NotesException {
      this.gotoChild((ViewEntry)var1);
      return this.currEntry;
   }

   public boolean gotoNextSibling(lotus.domino.ViewEntry var1) throws NotesException {
      return this.navFlat ? this.gotoRelEntry(1, (ViewEntry)var1) : this.gotoRelEntry(5, (ViewEntry)var1);
   }

   public lotus.domino.ViewEntry getNextSibling(lotus.domino.ViewEntry var1) throws NotesException {
      this.gotoNextSibling((ViewEntry)var1);
      return this.currEntry;
   }

   public boolean gotoPrevSibling(lotus.domino.ViewEntry var1) throws NotesException {
      return this.navFlat ? this.gotoRelEntry(9, (ViewEntry)var1) : this.gotoRelEntry(6, (ViewEntry)var1);
   }

   public lotus.domino.ViewEntry getPrevSibling(lotus.domino.ViewEntry var1) throws NotesException {
      this.gotoPrevSibling((ViewEntry)var1);
      return this.currEntry;
   }

   public boolean gotoParent(lotus.domino.ViewEntry var1) throws NotesException {
      return this.navFlat ? this.gotoRelEntry(9, (ViewEntry)var1) : this.gotoRelEntry(3, (ViewEntry)var1);
   }

   public lotus.domino.ViewEntry getParent(lotus.domino.ViewEntry var1) throws NotesException {
      this.gotoParent((ViewEntry)var1);
      return this.currEntry;
   }

   public int getCacheSize() {
      return 0;
   }

   public void setCacheSize(int var1) {
   }

   public int getMaxLevel() {
      return this.maxLevel;
   }

   public void setMaxLevel(int var1) throws NotesException {
      if (var1 >= 0 && var1 <= 30 && var1 >= this.navMinLevel) {
         this.maxLevel = var1;
      } else {
         throw new NotesException(4392, JavaString.resource.getString("invalid_maximum_navigation_level"));
      }
   }

   public lotus.domino.View getParentView() {
      return this.parentView;
   }
}
